@@ -11,13 +11,27 @@ utils::globalVariables(
     "AptName",
     "array_id",
     "blank_col",
+    "ColCheck",
     "Dilution",
     "eLOD",
     "feature",
+    "Group",
+    "GroupCount",
+    "Normalization Scale Factor",
+    "Organism",
     "prefix",
+    "Response",
+    "RowCheck",
     "rn",
+    "SampleId",
+    "SampleType",
     "SeqId",
     "seqid",
-    "value"
+    "SubjectCount",
+    "SubjectId",
+    "TargetFullName",
+    "Type",
+    "value",
+    "Value"
   )
 )
